summaryrefslogtreecommitdiffstats
path: root/include/crm/common/xml_compat.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/crm/common/xml_compat.h')
-rw-r--r--include/crm/common/xml_compat.h15
1 files changed, 14 insertions, 1 deletions
diff --git a/include/crm/common/xml_compat.h b/include/crm/common/xml_compat.h
index bb49b68..85e39ff 100644
--- a/include/crm/common/xml_compat.h
+++ b/include/crm/common/xml_compat.h
@@ -31,6 +31,9 @@ extern "C" {
#define XML_PARANOIA_CHECKS 0
//! \deprecated This function will be removed in a future release
+xmlDoc *getDocPtr(xmlNode *node);
+
+//! \deprecated This function will be removed in a future release
int add_node_nocopy(xmlNode * parent, const char *name, xmlNode * child);
//! \deprecated This function will be removed in a future release
@@ -51,13 +54,23 @@ gboolean apply_xml_diff(xmlNode *old_xml, xmlNode *diff, xmlNode **new_xml);
//! \deprecated Do not use (will be removed in a future release)
void crm_destroy_xml(gpointer data);
-//! \deprecated Use crm_xml_add() with "true" or "false" instead
+//! \deprecated Check children member directly
+gboolean xml_has_children(const xmlNode *root);
+
+//! \deprecated Use crm_xml_add() with "true" or "false" instead
static inline const char *
crm_xml_add_boolean(xmlNode *node, const char *name, gboolean value)
{
return crm_xml_add(node, name, (value? "true" : "false"));
}
+//! \deprecated Use name member directly
+static inline const char *
+crm_element_name(const xmlNode *xml)
+{
+ return (xml == NULL)? NULL : (const char *) xml->name;
+}
+
#ifdef __cplusplus
}
#endif